############################################################
Analysing WL data for a resource
############################################################

.. autofunction:: wrap_technote.scripts.waterlevels_run

Step 1. Water level data validation
=====================================

.. autofunction:: wrap_technote.scripts.step1_data_validation

Step 2. Calculating recovered and ranked water levels
===========================================================

.. autofunction:: wrap_technote.scripts.step2_defining_recovered_wls

Step 3. Linear water level trends
===========================================================

.. autofunction:: wrap_technote.scripts.step3_waterlevel_trends

Static webpage for the water level data analysis
================================================================================

.. autofunction:: wrap_technote.scripts.create_static_waterlevels_page